@@ -154,9 +154,6 @@ brasero_status_dialog_update (BraseroStatusDialog *self,
 static void
 brasero_status_dialog_session_ready (BraseroStatusDialog *dialog)
 {
-	BraseroStatusDialogPrivate *priv;
-
-	priv = BRASERO_STATUS_DIALOG_PRIVATE (dialog);
 	gtk_dialog_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 }
 
@@ -229,7 +226,7 @@ brasero_status_dialog_deep_directory_cb (BraseroTrackDataCfg *project,
 
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (message),
 						  _("The children of this directory will have 7 parent directories."
-						    "\nBrasero can create an image of such a file hierarchy and burn it; but the disc may not be readable on all operating systems."
+						    "\nBrasero can create an image of such a file hierarchy and burn it but the disc may not be readable on all operating systems."
 						    "\nNote: Such a file hierarchy is known to work on Linux."));
 
 	gtk_dialog_add_button (GTK_DIALOG (message), _("Ne_ver Add Such File"), GTK_RESPONSE_REJECT);
@@ -291,7 +288,7 @@ brasero_status_dialog_2G_file_cb (BraseroTrackDataCfg *track,
 
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (message),
 						  _("The size of the file is over 2 GiB. Files larger than 2 GiB are not supported by the ISO9660 standard in its first and second versions (the most widespread ones)."
-						    "\nIt is recommended to use the third version of the ISO9660 standard, which is supported by most operating systems, including Linux and all versions of Windows ©."
+						    "\nIt is recommended to use the third version of the ISO9660 standard, which is supported by most operating systems, including Linux and all versions of Windows™."
 						    "\nHowever, Mac OS X cannot read images created with version 3 of the ISO9660 standard."));
 
 	gtk_dialog_add_button (GTK_DIALOG (message), _("Ne_ver Add Such File"), GTK_RESPONSE_REJECT);
